Utilities
=========

.. autofunction:: emiproc.utilities.get_country_mask

.. autofunction:: emiproc.utilities.get_natural_earth

.. autofunction:: emiproc.utilities.get_timezone_mask

.. autofunction:: emiproc.utilities.get_timezones


Emissions Informations
----------------------

.. autoclass:: emiproc.inventories.EmissionInfo